Index: content/child/child_thread_impl.cc |
diff --git a/content/child/child_thread_impl.cc b/content/child/child_thread_impl.cc |
index bfb1f3a21bf3d4fe20fd40242e37debfd6673457..51c1bb28e6c9456251be4607e0aeb625355bbdc7 100644 |
--- a/content/child/child_thread_impl.cc |
+++ b/content/child/child_thread_impl.cc |
@@ -39,6 +39,7 @@ |
#include "content/child/fileapi/file_system_dispatcher.h" |
#include "content/child/fileapi/webfilesystem_impl.h" |
#include "content/child/geofencing/geofencing_message_filter.h" |
+#include "content/child/memory/child_memory_message_filter.h" |
#include "content/child/mojo/mojo_application.h" |
#include "content/child/notifications/notification_dispatcher.h" |
#include "content/child/power_monitor_broadcast_source.h" |
@@ -434,10 +435,11 @@ void ChildThreadImpl::Init(const Options& options) { |
channel_->AddFilter(geofencing_message_filter_->GetFilter()); |
if (!IsInBrowserProcess()) { |
// In single process mode, browser-side tracing will cover the whole |
// process including renderers. |
channel_->AddFilter(new tracing::ChildTraceMessageFilter( |
ChildProcess::current()->io_task_runner())); |
+ channel_->AddFilter(new ChildMemoryMessageFilter()); |
} |
// In single process mode we may already have a power monitor |
@@ -434,10 +435,11 @@ void ChildThreadImpl::Init(const Options& options) { |
channel_->AddFilter(geofencing_message_filter_->GetFilter()); |
if (!IsInBrowserProcess()) { |
- // In single process mode, browser-side tracing will cover the whole |
- // process including renderers. |
+ // In single process mode, browser-side tracing and memory will cover the |
+ // whole process including renderers. |
channel_->AddFilter(new tracing::ChildTraceMessageFilter( |
ChildProcess::current()->io_task_runner())); |